/*
 * Copyright(c)  2002  Rijkswaterstaat
 *                     Adviesdienst Verkeer en Vervoer
 *                     WSRA
 * File:               CRAPTAB.C
 *
 * Regelprogramma vri: Voorbeeldregeling detectiebewaking
 *
 * datum:              23 maart 1999
 * gewijzigd dd.:      12 maart 2003
 *                     - det_bew_ma aangepast
 *                     - extra functie verl_bij_DetBew toegevoegd
 *                     - omzetting naar FLASH
 *                     18 april 2005
 *                      - aanpassing aan RWS-C versie 8.15
 * versie:             7.1
 */

#include "crtypes.h"
#include "crapcod.h"
#include "craptab.h"
#include "ccie_int.h"
#include "crapdef.h"

/*
 * =============================================================
 * declaraties t.b.v. het blokkenschema
 * =============================================================
 */

/*     BLOKKEN schema                                           */
struct BLOKKEN  BLOKKEN_tabel[] = {
/*     blok:    sg:     toewijzing:                             */
/*     BKl,     SGn,    PRIM + WSGR + ALT,                      */

       BK1,     SG02,   PRIM + WSGR,
       BK1,     SG08,   PRIM + WSGR,

       BK2,     SG05,   PRIM,
       BK2,     SG11,   PRIM,

       BK3,     SG28,   PRIM,
       STOP};

struct WB  WB_tabel[] = {BK1,STOP};

/*     CONFLICT- en (garantie)ontruimingstijden matrix          */
struct CONFLICT  CONFLICT_tabel[] = {
/*     sg:       conflicterende sg:   GO_TIJD:  O_TIJD:         */
       SG02,     SG05,                2.0,      2.0,
       SG02,     SG11,                2.0,      2.0,
       SG02,     SG28,                2.0,      2.0,
       SG05,     SG02,                2.0,      2.0,
       SG05,     SG08,                2.0,      2.0,
       SG05,     SG28,                2.0,      2.0,
       SG08,     SG05,                2.0,      2.0,
       SG08,     SG11,                2.0,      2.0,
       SG08,     SG28,                2.0,      2.0,
       SG11,     SG02,                2.0,      2.0,
       SG11,     SG08,                2.0,      2.0,
       SG11,     SG28,                2.0,      2.0,
       SG28,     SG02,                2.0,      2.0,
       SG28,     SG05,                2.0,      2.0,
       SG28,     SG08,                2.0,      2.0,
       SG28,     SG11,                2.0,      2.0,
       STOP};

struct FICT_CONFLICT  FICT_CONFLICT_tabel[]  = {STOP};
struct SG_BS_H5t  SG_BS_H5t_tabel[]          = {STOP};
struct SG_BS_H5ac  SG_BS_H5ac_tabel[]        = {STOP};
struct SG_BS_H66  SG_BS_H66_tabel[]          = {STOP};

/*     SignaalGroep_TIJDEN tabel                                */
struct SG_TIJDEN  SG_TIJDEN_tabel[] = {
/*            instellingen van de tijden:                       */
/*     sg:    GG_TIJD:  VG_TIJD:  GGL_TIJD:  GL_TIJD:  GR_TIJD: */
/*     SGn,    x.y,      x.y,      x.y,       x.y,      x.y,    */
       SG02,   4.0,      6.0,      3.0,       4.0,      2.0,
       SG05,   4.0,      6.0,      3.0,       3.0,      2.0,
       SG08,   4.0,      6.0,      3.0,       4.0,      2.0,
       SG11,   4.0,      6.0,      3.0,       3.0,      2.0,
       SG28,   4.0,      6.0,      3.0,       3.0,      2.0,
       STOP};

/*     MG_TIJDEN tabel                                          */
struct MG_TIJDEN  MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD:  MG_TIJD1:  MG_TIJD2:  MG_TIJD3:         */
/*     SGn,    x.y,      x.y,       x.y,       x.y,             */
       SG02,  20.0,       NG,        NG,        NG,
       SG05,  20.0,       NG,        NG,        NG,
       SG08,  20.0,       NG,        NG,        NG,
       SG11,  20.0,       NG,        NG,        NG,
       SG28,  10.0,       NG,        NG,        NG,
       STOP};

struct E_MG_TIJDEN  E_MG_TIJDEN_tabel[] = {STOP};

/*     HiaatTIJDEN tabel                                        */
struct H_TIJDEN  H_TIJDEN_tabel[] = {
/*               instellingen (x.y of NG) van de tijden:        */
/*     sg:       H1e_TIJD:   H2e_TIJD:                          */
/*     SGn,       x.y,        x.y,                              */
       SG02,      0.0,        1.0,
       SG05,      0.0,         NG,
       SG08,      0.0,        1.0,
       SG11,      0.0,         NG,
       SG28,      0.0,         NG,
       STOP};

/*     Extra-HiaatTIJDEN tabel                                  */
struct E_H_TIJDEN  E_H_TIJDEN_tabel[] = {
/*               instellingen (x.y of NG) van de tijden:        */
/*     sg:       E_H1e_TIJD:    E_H2e_TIJD:                     */
/*     SGn,       x.y,           x.y,                           */
       SG02,      2.0,           3.0,
       SG05,      2.0,            NG,
       SG08,      2.0,           3.0,
       SG11,      2.0,            NG,
       SG28,       NG,            NG,
       STOP};

/*     SignaalGroep-DETECTIE tabel                              */
struct SG_DETECTIE           SG_DETECTIE_tabel[] = {
/*     D():     type:        sg:     toewijzing:                */
/*     SGn_i,   DP (of DK),  SGn,    AVR + BS_H5p + H1e + H2e,  */
       SG02_1,  DP + DFU,          SG02,         BS_H5p,
       SG02_2,  DP + DFU,          SG02,   AVR + H1e,
       SG02_3,  DP + DFU,          SG02,   GEEN,
       SG02_4,  DP + DFU,          SG02,   AVR + H2e,
       SG02_5,  DP + DFU,          SG02,   AVR + H2e,

       SG05_1,  DP + DFU,          SG05,   AVR + BS_H5p,
       SG05_2,  DP + DFU,          SG05,   AVR + H1e,

       SG08_1,  DP + DFU,          SG08,   AVR + BS_H5p,
       SG08_2,  DP + DFU,          SG08,   AVR + H1e,
       SG08_3,  DP + DFU,          SG08,   AVR + H2e,

       SG11_1,  DP + DFU,          SG11,   AVR + BS_H5p,
       SG11_2,  DP + DFU,          SG11,   AVR + H1e,

       SG28_1,  DP + DFU,          SG28,         H1e,
       SG28_2,  DP + DFU,          SG28,   GEEN,
       SG28_3,  DK + DFU,          SG28,   AVR,
       STOP};

struct SG_RGA     SG_RGA_tabel[] = {
/*     1e D():    2e D():    koplus D():  sg:   paarnr:  TIJD():*/
/*     SGn_i,     SGn_j,     SGn_k,       SGn,       x,  SGn_l, */
       SG02_2,    SG02_3,    SG02_1,      SG02,      1,  rga2,
       SG28_1,    SG28_2,    SG28_1,      SG28,      1,  rga28,
STOP};


struct FIETS_VOETG_R  FIETS_VOETG_R_tabel[] =   {28, STOP};
struct SG_MAH3     SG_MAH3_tabel[] =            {STOP};
struct SG_PPAH     SG_PPAH_tabel[] =            {STOP};
struct SG_WSRH     SG_WSRH_tabel[] =            {STOP};

struct TIJDEN      TIJDEN_tabel[] =  {
/*     TIJD():                     instelling:                  */
/*     SGn_i,                       x.y,                        */
       rga2,                        2.0,
       rga28,                       2.0,
       STOP};

struct KLOKKEN     KLOKKEN_tabel[] =            {STOP};
struct SCHAKELAAR  SCHAKELAAR_tabel[] =         {STOP};
struct EGGPARMS    EGGPARMS_tabel[] =           {STOP};
struct EPARMS      EPARMS_tabel[] =             {STOP};
struct BK_OPTIE    BO_OP_tabel[] =              {STOP};

Bool MA_funct_02 (void){ return RGAH(SG02, 1); }
Bool MA_funct_28 (void){ return RGAH(SG28, 1); }
struct SG_OPTIE    MA_OP_tabel[] = {
/*     optie voor sg:     inhoud van de optie: */
/*     SGn,               functie, */
       SG02,              MA_funct_02,
       SG28,              MA_funct_28,
       STOP};

struct SG_BK_OPTIE PPP_OP_tabel[] =             {STOP};
struct SG_OPTIE    MVG_OP_tabel[] =             {STOP};
struct SG_OPTIE    TR_OP_tabel[] =              {STOP};

struct SG_OPTIE           VAA_OP_tabel[] = {
/*     SGn,               WAAR (of functie),                    */
       SG02,              WAAR,
       SG05,              WAAR,
       SG08,              WAAR,
       SG11,              WAAR,
       SG28,              WAAR,
       STOP};
struct SG_OPTIE           PPV_OP_tabel[] = {
/*     SGn,               WAAR (of functie),                    */
       SG02,              WAAR,
       SG05,              WAAR,
       SG08,              WAAR,
       SG11,              WAAR,
       SG28,              WAAR,
       STOP};

/*
 * ===============================================================
 * tabel met gekoppelde regelingen
 * ===============================================================
 */
struct SG_OPTIE           PPB_OP_tabel[] = {STOP};
struct SG_BK_OPTIE        PPA_OP_tabel[] = {STOP};
struct SG_BK_OPTIE        VNM_OP_tabel[] = {STOP};
struct SG_OPTIE           AFK_OP_tabel[] = {STOP};
struct SG_OPTIE           BL_OP_tabel[]  = {STOP};
struct SG_OPTIE           RVG_OP_tabel[] = {STOP};
struct SG_OPTIE           VAG_OP_tabel[] = {STOP};
struct SG_OPTIE           VMG_OP_tabel[] = {STOP};
struct KOPPEL             KOPPEL_tabel[] = {STOP};
/*     REGELINGtabel                                            */

struct REGELING   REGELING_tabel[] = {
/*     Nummer                                                   */
       1,
       STOP};