/*
 * Copyright(c)  2002  Rijkswaterstaat
 *                     Adviesdienst Verkeer en Vervoer
 *                     WSRA
 * File:               DETBEW.INC
 *
 * datum:              23 maart 1999
 * gewijzigd dd.:      12 maart 2003
 *                     - det_bew_ma aangepast
 *                     - extra functie verl_bij_DetBew toegevoegd
 *                     18 april 2005
 *                     - aanpassing aan RWS-C versie 8.15
 * versie:             7.1
 */

/* prototype's en define's t.b.v. DETBEW.C */

#include <crsg.h>
#include <stdarg.h>


#define VERL                1
#define NVRL                0
#define END                -3

void det_bew_ma        (Int16, Int16, ...);
void det_bew_ma_koplus (Int16, Int16);
void det_bew_rga2      (Int16, Int16);
void det_bew_rga3      (Int16, Int16);
void overn_vag1_eh1    (Int16, Int16, Int16);
void overn_vag2_eh2    (Int16, Int16, Int16);
void overn_verweg2_eh2 (Int16, Int16, Int16);
void verl_bij_DetBew   (void);

Int16 SGvl[NUMSG];



/* 1. det_bew_ma (Parm1, Parm2, Parm3, Parm4,...,END) */
/* -------------------------------------------------- */


void det_bew_ma(Int16 n, Int16 v, ...)
{
  va_list argpt;                 /* variabele argumentenlijst */
  Int16    dpnr;                 /* arraynummer van de detectielus */
  Bool    do_ma;                 /* TRUE bij detectiefout op alle betreffende lussen */

  do_ma = TRUE;                  /* in beginsel TRUE, tenzij... */
  va_start(argpt,v);

  do
  {  dpnr= va_arg(argpt, int);
     if ((dpnr >= 0) && (dpnr>END))
     {
        if (!DFOUT(dpnr))
        do_ma = FALSE;
        SGvl[n] = 0;
     }
  }  while (dpnr>END);

  va_end(argpt);               /* maak var. arg-lijst leeg */
  if (do_ma){
     if ( R(n) && !GR_TIJD(n) )  set_MA(n);
     if (v)
       SGvl[n] = 1;
     else
       SGvl[n] = 0;
  }
}

/* 1a. verl_bij_DetBew() */
/* --------------------- */

void verl_bij_DetBew(void){
Int16 i;

  for (i=0; i<NUMSG; i++ )
  {
    if (SGvl[i] == 1)
    {
      sgn_n = i;
      if (!ov_o)     herstart_H1e_TIJD(i);
      if (!ov_x)     herstart_H2e_TIJD(i);
    } 
  }
}



/* 2. det_bew_ma_koplus (Parm1, Parm2)                */
/* -------------------------------------------------- */

void det_bew_ma_koplus (Int16 d, Int16 s){

   if (DFOUT(d)){
      if ( R(s) && !GR_TIJD(s) )  set_MA(s);
      }
}


/* 3. overn_vag1_eh1(Parm1, Parm2, Parm3)             */
/* ----------------------------------------------------
   als detector Dn.2 (lange lus) stoort en Dn.1 (koplus) NIET,
   overnemen van de 1eHiaat functie door detector Dn.1 (koplus) met de
   Extra 1e Hiaattijd. In het geval dat de koplus eerder stoorde als
   de lange lus dan geen overname, als de koplus daarna niet meer gestoord
   is en de lange lus nog steeds volgt ook de overname.

   als detector Dn.2 (lange lus) niet meer stoort intrekken van de
   1eHiaat functie van detector Dn.1 (koplus) en de normale 1e Hiaattijd
   kiezen.
*/
void overn_vag1_eh1 (Int16 d1, Int16 d2, Int16 sgn){
  if ( (begin_DFOUT(d2) && !DFOUT(d1)) ||
       (einde_DFOUT(d1) && DFOUT(d2))   ) {
          set_H1e_toewijzing_D(d1);
          kies_E_H1e_TIJD(sgn);
  }
  if ( einde_DFOUT(d2) ) {
          reset_H1e_toewijzing_D(d1);
          kies_H1e_TIJD(sgn);
  }
}


/* 4. overn_vag2_eh2(Parm1, Parm2, Parm3)             */
/* -----------------------------------------------------
   als detector Dn.3 (2eVAG lus) stoort en Dn.2 (lange lus) NIET,
   overnemen van de 2eHiaat functie door detector Dn.2 (lange lus) met
   de Extra 2e Hiaattijd. In het geval dat de lange lus eerder stoorde als
   de 2eVAG lus dan geen overname, als de lange lus daarna niet meer gestoord
   is en de 2eVAG lus nog steeds volgt ook de overname.

   als detector Dn.3 (2eVAG lus) niet meer stoort intrekken van de
   1eHiaat functie van detector Dn.2 (lange lus) en de normale 2e Hiaattijd
   kiezen.
*/
void overn_vag2_eh2 (Int16 d2, Int16 d3, Int16 sgn){
  if ( (begin_DFOUT(d3) && !DFOUT(d2)) ||
       (einde_DFOUT(d2) && DFOUT(d3))   ) {
          set_H2e_toewijzing_D(d2);
          kies_E_H2e_TIJD(sgn);
  }
  if ( einde_DFOUT(d3) ) {
          reset_H2e_toewijzing_D(d2);
          kies_H2e_TIJD(sgn);
  }
}


/* 5. overn_verweg2_eh2(Parm1, Parm2, Parm3)          */
/* ----------------------------------------------------
   overn_verweg2_eh2 is bedoeld voor een situatie met twee achter elkaar
   gelegen verweglussen. Indien de eerste verweglus defect is, wordt de
   extra 2e hiaattijd gekozen.
   Bij een defect aan de tweede verweglus of aan beide lussen is er geen actie.
*/
void overn_verweg2_eh2 (Int16 dv1, Int16 dv2, Int16 sgn){
  if ((begin_DFOUT(dv1) && !DFOUT(dv2)) ||
      (einde_DFOUT(dv2) && DFOUT(dv1)) ) {
         kies_E_H2e_TIJD(sgn);
  }
  if (einde_DFOUT(dv1) && !DFOUT(dv2))  {
         kies_H2e_TIJD(sgn);
  }
}


/* 6. det_bew_rga2(Parm1, Parm2)                       */
/* -------------------------------------------------------

/* De richtinggevoelige aanvraag kan worden gebruikt om een aanvraag na
   bezettijd op de koplus te maken. Koplus, d1 en d2 zijn dezelfde lus. Voor
   een defect aan zo'n lus zijn geen maatregelen gedefinieerd.
   Gebruik zonodig de det_bew_ma of det_bew_ma_koplus.
   RGA2 is bedoeld voor een situatie met twee lussen: koplus en d2 (de koplus
   en d1 betreffen dezelfde lus).
   Als de koplus stoort, krijgt d2 een aanvraagfunctie.
   Als d2 stoort, worden geen maatregelen getroffen. Op de koplus ontstaat na
   een bezettijd een aanvraag.
   Valkuil: een bezettijd van 0 seconden op de koplus.
   Voor een defect aan beide lussen: gebruik det_bew_ma.
*/
void det_bew_rga2      (Int16 dkop, Int16 d2){
   if ( (begin_DFOUT(dkop) && !DFOUT(d2)) || (einde_DFOUT(d2) && DFOUT(dkop)) )
      { set_AVR_toewijzing_D(d2); }
   if ( einde_DFOUT(dkop) )
      { reset_AVR_toewijzing_D(d2); }
}


/* 7. det_bew_rga3(Parm1, Parm2)                       */
/* -------------------------------------------------------
   RGA3 is bedoeld voor een situatie met drie lussen: koplus, d1 en d2
   Als lus d1 of d2 stoort, krijgt de resterende lus een aanvraagfunctie.
   Als beide lussen kapot zijn, worden geen maatregelen getroffen. Op de
   koplus ontstaat na een bezettijd een aanvraag.
   Valkuil: een bezettijd van 0 seconden op de koplus.
   Voor een defect aan alle drie de lussen: gebruik det_bew_ma.
*/
void det_bew_rga3      (Int16 d1, Int16 d2){
   if ( (begin_DFOUT(d1) && !DFOUT(d2)) || (einde_DFOUT(d2) && DFOUT(d1)) )
      { set_AVR_toewijzing_D(d2); }
   if ( einde_DFOUT(d1) )
      { reset_AVR_toewijzing_D(d2); }
   if ( (begin_DFOUT(d2) && !DFOUT(d1)) || (einde_DFOUT(d1) && DFOUT(d2)) )
      { set_AVR_toewijzing_D(d1); }
   if ( einde_DFOUT(d2) )
      { reset_AVR_toewijzing_D(d1); }
}
